@@ -242,7 +242,7 @@ namespace Breeze
         for( int i = widgets.size() - 1; i>=0; i-- )
         {
             QWidget* w = widgets.at(i);
-            w->render( &p, -widget->mapTo( w, rect.topLeft() ), rect, nullptr );
+            w->render( &p, -widget->mapTo( w, rect.topLeft() ), rect, {} );
         }
 
         // end
